// Copyright (c) 2022 by István Váradi

// This file is part of VSCPL, a simple cross-platform utility library

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#pragma once

//------------------------------------------------------------------------------

#include "Socket.h"

//------------------------------------------------------------------------------

namespace hu { namespace varadiistvan { namespace scpl { namespace io {

//------------------------------------------------------------------------------

/**
 * A socket that works on a TCP connection.
 */
class TCPSocket : public Socket
{
private:
    /**
     * Construct the socket with the given parameters.
     */
    TCPSocket(int fd, Waiter* waiter = 0,
              size_t readingCapacity = DEFAULT_CAPACITY,
              size_t writingCapacity = DEFAULT_CAPACITY);

    friend class SocketAcceptor<TCPSocket>;
};

//------------------------------------------------------------------------------
// Inline definitions
//------------------------------------------------------------------------------

inline TCPSocket::TCPSocket(int fd, Waiter* waiter,
                            size_t readingCapacity,
                            size_t writingCapacity) :
    Socket(fd, waiter, readingCapacity, writingCapacity)
{
}

//------------------------------------------------------------------------------

} /* namespace hu::varadiistvan::scpl::io */ } /* namespace hu::varadiistvan::scpl */ } /* namespace hu::varadiistvan */ } /* namespace hu */

//------------------------------------------------------------------------------

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
